@@ -74,7 +74,7 @@ def test_build_U():
     S.SigmaSqr = None
     S.Lambda = None
     # build_Psi() and build_U() are called in fun_likelihood
-    S.set_de_bounds()
+    S._set_de_bounds()
     if S.model_optimizer.__name__ == "dual_annealing":
         result = S.model_optimizer(func=S.fun_likelihood, bounds=S.de_bounds)
     elif S.model_optimizer.__name__ == "differential_evolution":
@@ -95,7 +95,7 @@ def test_build_U():
     # Finally, set new theta and p values and update the surrogate again
     # for new_theta_p_Lambda in de_results["x"]:
     new_theta_p_Lambda = result["x"]
-    S.extract_from_bounds(new_theta_p_Lambda)
+    S._extract_from_bounds(new_theta_p_Lambda)
     S.build_Psi()
     S.build_U()
     assert S.U.shape[0] == ni
